# tree-sitter-nuon

[![CI][ci]](https://github.com/melMass/tree-sitter-nuon/actions/workflows/ci.yml)
<!-- [![crates][crates]](https://crates.io/crates/tree-sitter-nuon) -->
<!-- [![npm][npm]](https://www.npmjs.com/package/tree-sitter-nuon) -->
<!-- [![pypi][pypi]](https://pypi.org/project/tree-sitter-nuon) -->

NUON grammar for [tree-sitter](https://github.com/tree-sitter/tree-sitter)

[ci]: https://img.shields.io/github/actions/workflow/status/melMass/tree-sitter-nuon/ci.yml?logo=github&label=CI
<!-- [npm]: https://img.shields.io/npm/v/tree-sitter-nuon?logo=npm -->
<!-- [crates]: https://img.shields.io/crates/v/tree-sitter-nuon?logo=rust -->
<!-- [pypi]: https://img.shields.io/pypi/v/tree-sitter-nuon?logo=pypi&logoColor=ffd242 -->
